==> seedsui-react-2.9.3.tgz: package/es/InputStar/InputStar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Star from './../Star';

var InputStar = (_temp = _class = function (_Component) {
  _inherits(InputStar, _Component);

  // 全局配置
  function InputStar(props, context) {
    _classCallCheck(this, InputStar);

    return _possibleConstructorReturn(this, _Component.call(this, props, context));
  }

  InputStar.prototype.onChange = function onChange(e, argNum) {
    // 全局配置
    var _context$locale = this.context.locale,
        locale = _context$locale === undefined ? {} : _context$locale;
    var _props = this.props,
        value = _props.value,
        min = _props.min,
        onChange = _props.onChange,
        onError = _props.onError;

    var num = argNum;
    if (num < min) {
      if (onError) {
        onError(e, {
          msg: '' + (locale['hint_cannot_be_less_than'] || '不能小于') + min + (locale['star'] || '颗星'),
          select: num,
          min: min,
          value: min
        });
      }
      num = min;
    }
    if (onChange) onChange(e, num);
  };

  InputStar.prototype.render = function render() {
    var _this2 = this;

    var _props2 = this.props,
        max = _props2.max,
        min = _props2.min,
        value = _props2.value,
        onChange = _props2.onChange,
        onError = _props2.onError,
        others = _objectWithoutProperties(_props2, ['max', 'min', 'value', 'onChange', 'onError']);

    var stars = [];
    for (var i = 1; i <= max; i++) {
      stars.push(i);
    }
    var current = value;
    if (current < min) current = min;
    return React.createElement(
      'div',
      _extends({}, others, { className: 'input-star' + (others.className ? ' ' + others.className : '') }),
      stars.map(function (index) {
        return React.createElement(Star, { onClick: function onClick(e) {
            _this2.onChange(e, index);
          }, key: index, className: index <= current ? 'active' : '' });
      })
    );
  };

  return InputStar;
}(Component), _class.contextTypes = {
  locale: PropTypes.object,
  portal: PropTypes.object
}, _class.defaultProps = {
  value: 0,
  min: 0,
  max: 5
}, _temp);
export { InputStar as default };
InputStar.propTypes = process.env.NODE_ENV !== "production" ? {
  min: PropTypes.number,
  max: PropTypes.number,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  onChange: PropTypes.func,
  onError: PropTypes.func // ({e, {msg: '错误信息', select: '当前选中', min: '最小值', value: '矫正后的值'}})
} : {};

==> seedsui-react-2.9.4.tgz: package/es/InputStar/InputStar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Star from './../Star';

var InputStar = (_temp = _class = function (_Component) {
  _inherits(InputStar, _Component);

  // 全局配置
  function InputStar(props, context) {
    _classCallCheck(this, InputStar);

    return _possibleConstructorReturn(this, _Component.call(this, props, context));
  }

  InputStar.prototype.onChange = function onChange(e, argNum) {
    // 全局配置
    var _context$locale = this.context.locale,
        locale = _context$locale === undefined ? {} : _context$locale;
    var _props = this.props,
        value = _props.value,
        min = _props.min,
        onChange = _props.onChange,
        onError = _props.onError;

    var num = argNum;
    if (num < min) {
      if (onError) {
        onError(e, {
          errMsg: '' + (locale['hint_cannot_be_less_than'] || '不能小于') + min + (locale['star'] || '颗星'),
          select: num,
          min: min,
          value: min
        });
      }
      num = min;
    }
    if (onChange) onChange(e, num);
  };

  InputStar.prototype.render = function render() {
    var _this2 = this;

    var _props2 = this.props,
        max = _props2.max,
        min = _props2.min,
        value = _props2.value,
        onChange = _props2.onChange,
        onError = _props2.onError,
        others = _objectWithoutProperties(_props2, ['max', 'min', 'value', 'onChange', 'onError']);

    var stars = [];
    for (var i = 1; i <= max; i++) {
      stars.push(i);
    }
    var current = value;
    if (current < min) current = min;
    return React.createElement(
      'div',
      _extends({}, others, { className: 'input-star' + (others.className ? ' ' + others.className : '') }),
      stars.map(function (index) {
        return React.createElement(Star, { onClick: function onClick(e) {
            _this2.onChange(e, index);
          }, key: index, className: index <= current ? 'active' : '' });
      })
    );
  };

  return InputStar;
}(Component), _class.contextTypes = {
  locale: PropTypes.object,
  portal: PropTypes.object
}, _class.defaultProps = {
  value: 0,
  min: 0,
  max: 5
}, _temp);
export { InputStar as default };
InputStar.propTypes = process.env.NODE_ENV !== "production" ? {
  min: PropTypes.number,
  max: PropTypes.number,
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  onChange: PropTypes.func,
  onError: PropTypes.func // ({e, {errMsg: '错误信息', select: '当前选中', min: '最小值', value: '矫正后的值'}})
} : {};
